@@ -5,7 +5,7 @@ use warnings;
 
 use Acme::Alien::DontPanic;
 
-our $VERSION = '0.029';
+our $VERSION = '0.030';
 require DynaLoader;
 our @ISA = 'DynaLoader';
 __PACKAGE__->bootstrap($VERSION);
@@ -54,7 +54,7 @@ L<Acme::Alien::DontPanic>
 
 =head1 SOURCE REPOSITORY
 
-L<http://github.com/jberger/Alien-Base-Extras>
+L<http://github.com/Perl5-Alien/Acme-Ford-Prefect>
 
 =head1 AUTHOR
 
